module Pages.Dodgers exposing (Model, Msg, page)

import Config.Colour as T exposing (..)
import Config.Format as O exposing (..)
import Config.Identity as I exposing (..)
import Cuckery.CuckList.AdamSinger exposing (cuckAdamSinger)
import Cuckery.CuckList.AnnChilders exposing (cuckAnnChilders)
import Cuckery.CuckList.AnthonyGustin exposing (cuckAnthonyGustin)
import Cuckery.CuckList.BartKay exposing (cuckBartKay)
import Cuckery.Helpers exposing (..)
import Effect exposing (Effect)
import Element exposing (..)
import Element.Border as D
import Element.Font as F
import Html.Attributes as H exposing (style)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Shared
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {}



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.none
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Model -> View Msg
view model =
    { title = dodgersName
    , attributes = []
    , element = dodgersContainer
    }


dodgersContainer : Element msg
dodgersContainer =
    topLevelContainer dodgersList


dodgersList : Element msg
dodgersList =
    column
        pageList
    <|
        List.map cuckMaker
            [ cuckAdamSinger
            , cuckAnnChilders
            , cuckAnthonyGustin
            , cuckBartKay
            ]



-- cucks =

--     , { cuckImage = "cucks/justinmares.png"
--       , cuckName = "Justin Mares"
--       , cuckSocial = "https://twitter.com/jwmares"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1329266554089869312?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "vegetable oils drive inflammation and are causally linked to weight gain and diseases of inflammation."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/josepheverett.png"
--       , cuckName = "Joseph Everett"
--       , cuckSocial = "https://twitter.com/JEverettLearned"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1535334822825971712?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "seed oils cause coronary heart disease and cancer."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1555138038740680704?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "seed oils cause coronary heart disease and cancer."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/kaitmalthaner.png"
--       , cuckName = "Kait Malthaner"
--       , cuckSocial = "https://twitter.com/healthcoachkait"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1503258756687306753?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "omega-6 is pro-inflammatory."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/kemminnick.png"
--       , cuckName = "Kem Minnick"
--       , cuckSocial = "https://twitter.com/kemminnick"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/kemminnick/status/1469336100300726273?s=20"
--               , dodgeDescription = dodgeType.ghostedMe
--               , dodgeProposition = "seed oils are not a significant, independent concern for the development of chronic diseases."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1476990862793986052?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "seed oils are not a significant, independent concern for the development of chronic diseases."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/kenberry.png"
--       , cuckName = "Ken Berry"
--       , cuckSocial = "https://twitter.com/KenDBerryMD"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1366524889067368449?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "type 2 diabetes is chronic carbohydrate overdose."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1539720236701589504?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "replacing animal fats with vegetable oils is dangerous."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1539721408372039680?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "replacing animal fats with vegetable oils is dangerous."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             , { dodgeLink = "https://x.com/TheNutrivore/status/1813969807521300615"
--               , dodgeDescription = dodgeType.inTooDeep
--               , dodgeProposition = propType.noClearProp
--               , dodgeNicksPosition = doxasticType.unevalState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/kevinstock.png"
--       , cuckName = "Kevin Stock"
--       , cuckSocial = "https://twitter.com/kevinstock12"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1530140722225102848?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = propType.noClearProp
--               , dodgeNicksPosition = doxasticType.unevalState
--               }
--             , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1534927799911317509?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "saturated fat does not cause cardiovascular disease."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/kylemamounis.png"
--       , cuckName = "Kyle Mamounis"
--       , cuckSocial = "https://twitter.com/Nutricrinology"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1389259133044477953?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "statins do not prevent cardiovascular events."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/marksisson.png"
--       , cuckName = "Mark Sisson"
--       , cuckSocial = "https://twitter.com/Mark_Sisson"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1488360227141419009?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = propType.noClearProp
--               , dodgeNicksPosition = doxasticType.unevalState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/martykendall.png"
--       , cuckName = "Marty Kendall"
--       , cuckSocial = "https://twitter.com/martykendall2"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1310548994804809729"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "to access your body fat, you need to deplete both glucose and fat from the blood first."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/maxlugavere.png"
--       , cuckName = "Max Lugavere"
--       , cuckSocial = "https://twitter.com/maxlugavere"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/maxlugavere/status/1517683567249149953?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "seed oils consumption is associated with an increased risk of CVD and Alzheimer's disease."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1518307089742848000?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "seed oils consumption is associated with an increased risk of CVD and Alzheimer's disease."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/maxlugavere/status/1518367365683064833?s=20"
--               , dodgeDescription = dodgeType.outrightNo
--               , dodgeProposition = "seed oils consumption is associated with an increased risk of CVD and Alzheimer's disease."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/michaelkummer.png"
--       , cuckName = "Michael Kummer"
--       , cuckSocial = "https://twitter.com/mkummer82"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/mkummer82/status/1465755847917715464?s=20"
--               , dodgeDescription = dodgeType.outrightNo
--               , dodgeProposition = "polyunsaturated fats cause cell damage, inflammation and metabolic dysfunction."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/michaelmanderville.png"
--       , cuckName = "Michael Manderville"
--       , cuckSocial = "https://twitter.com/MikeManderville"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1503036463306489856?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "a logically coherent position will have logically coherent answer to a logically coherent hypothetical."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/mike mutzel.png"
--       , cuckName = "Mike Mutzel"
--       , cuckSocial = "https://twitter.com/MikeMutzel"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1414457776982552576?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "COVID is nothing more than a cold to those that are healthy."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1584645853771616256?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "there is little to no association between saturated fat and cardiovascular disease."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/mikesweeney.png"
--       , cuckName = "Mike Sweeney"
--       , cuckSocial = "https://twitter.com/thelowcarb_rd"
--       , cuckDodges =
--             [ { dodgeLink = "https://x.com/TheNutrivore/status/1746962254052962552"
--               , dodgeDescription = dodgeType.outrightNo
--               , dodgeProposition = "vegan diets are nowhere near appropriate for the average person in society."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://x.com/thelowcarb_rd/status/1654182805964836865"
--               , dodgeDescription = dodgeType.ghostedMe
--               , dodgeProposition = "statistical gymnastics don't inform on real world mechanisms and hard outcomes."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1776652108646821913?t=Pf4sfAC1Z0pAcxGfQFr7oQ"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "Cheerios cause nausea, vomiting, seizures, irregular heartbeat, liver damage, and coma."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/nickeggleton.png"
--       , cuckName = "Nick Eggleton"
--       , cuckSocial = "https://twitter.com/NickEggleton"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1266626885703720961?s=20"
--               , dodgeDescription = dodgeType.outrightNo
--               , dodgeProposition = "polyunsaturated fats are poison."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/ninateicholz.png"
--       , cuckName = "Nina Teicholz"
--       , cuckSocial = "https://twitter.com/bigfatsurprise"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1556510529014882305?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "the science linking red meat to heart disease is very weak."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1467571763865210881?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "the available evidence supports limiting saturated fat intake for coronary heart disease risk reduction."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1538895943050878977?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "vegans pretend biology isn't real."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/norstrongchris.png"
--       , cuckName = "Norstrong Chris"
--       , cuckSocial = "https://twitter.com/NNMChris"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/NorstrongHealth/status/1416939281973530626?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "government funded USDA data is untrustworthy."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1534573919562350594?s=20"
--               , dodgeDescription = dodgeType.outrightNo
--               , dodgeProposition = "nutrition science as a whole is shit."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1534614710196260865?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "nutrition science as a whole is shit."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/paulmason.png"
--       , cuckName = "Paul Mason"
--       , cuckSocial = "https://twitter.com/DrPaulMason"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/Tom_Babington1/status/1361644276866830337?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = propType.noClearProp
--               , dodgeNicksPosition = doxasticType.unevalState
--               }
--             , { dodgeLink = "https://twitter.com/IdanOnTweeter/status/1373233980594618371?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "Ancel Keys' Seven Countries Study was flawed."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1461361726943760391?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "dietary linoleic acid is not a significant, independent concern for the development of chronic diseases."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/paulsaladino.png"
--       , cuckName = "Paul Saladino"
--       , cuckSocial = "https://twitter.com/paulsaladinomd"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1275912849999695872?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "subsidies for corn and soy are huge contributors to the chronic disease epidemic in the US."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/FoodFirst_Ty/status/1282847039596843009?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "seed oils are not a significant, independent risk factor for public health."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             , { dodgeLink = "https://twitter.com/FoodFirst_Ty/status/1283449495682904064?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "to exclude animal foods from the human diet is a nutritional catastrophe."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1282851963902636032?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "to exclude animal foods from the human diet is a nutritional catastrophe."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/The_Nutrivore/status/1469136550046814219?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "nutritional epidemiology generally provides good causal estimates."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1633831762509045766?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "linoleic acid wreaks havoc in your body."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/philipovadia.png"
--       , cuckName = "Philip Ovadia"
--       , cuckSocial = "https://twitter.com/ifixhearts"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1557791520324890624?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "sugar is the problem and meat is the solution."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             , { dodgeLink = "https://twitter.com/TheNutrivore/status/1558282337024180224?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "LDL doesn't cause coronary heart disease because it is just part of the arterial repair process."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/philippestephenson.png"
--       , cuckName = "Philippe Stephenson"
--       , cuckSocial = "https://twitter.com/TotalCytopath"
--       , cuckDodges =
--             [ { dodgeLink = "https://x.com/TheNutrivore/status/1779587012120715433"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "seed oils save lives."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/ralphnapolitano.png"
--       , cuckName = "Ralph Napolitano"
--       , cuckSocial = "https://twitter.com/DrRalphNap"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1462794580848300034?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "oatmeal is one of the worst foods you can eat and has no health benefits."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/raphaelsirtoli.png"
--       , cuckName = "Raphael Sirtoli"
--       , cuckSocial = "https://twitter.com/raphaels7"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/raphaels7/status/1475767357188579329?s=20"
--               , dodgeDescription = dodgeType.outrightNo
--               , dodgeProposition = "the diet-heart hypothesis is false."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             , { dodgeLink = "https://x.com/raphaels7/status/1783541746015654072"
--               , dodgeDescription = dodgeType.killScreen
--               , dodgeProposition = "seed oils are not a significant, independent risk factor for public health."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/robmeijer.png"
--       , cuckName = "Rob Meijer"
--       , cuckSocial = "https://twitter.com/EngineerDiet"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1435850829051793408?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = propType.noClearProp
--               , dodgeNicksPosition = doxasticType.unevalState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/robbwolf.png"
--       , cuckName = "Robb Wolf"
--       , cuckSocial = "https://twitter.com/robbwolf"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/TheNutrivore/status/1601624559647875072?s=20"
--               , dodgeDescription = dodgeType.outrightNo
--               , dodgeProposition = "ancestral foods are more likely to be antagonistically pleiotropic than novel foods."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/simongoddek.png"
--       , cuckName = "Simon Goddek"
--       , cuckSocial = "https://x.com/goddeketal"
--       , cuckDodges =
--             [ { dodgeLink = "https://x.com/TheNutrivore/status/1795673579931255233"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "vegetable oils increase the risk of heart disease."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             , { dodgeLink = "https://x.com/TheNutrivore/status/1795885929678196951"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "vegetable oils increase the risk of heart disease."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             , { dodgeLink = "https://x.com/TheNutrivore/status/1795674575315112396"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "vegetable oils increase the risk of heart disease."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/travisstatham.png"
--       , cuckName = "Travis Statham"
--       , cuckSocial = "https://twitter.com/Travis_Statham"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1461428023207489542?s=20"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "seed oils do not cause obesity."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             , { dodgeLink = "https://www.reddit.com/r/StopEatingSeedOils/comments/v457tu/how_vegetable_oils_make_us_fat_zero_acre/ic9u7wu/?utm_source=share"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "seed oils do not cause obesity."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/tristanhaggard.png"
--       , cuckName = "Tristan Haggard"
--       , cuckSocial = "https://twitter.com/Trxstxn4"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1513596227052527621?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "seed oils are toxic."
--               , dodgeNicksPosition = doxasticType.agnosticState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/trokalayjian.png"
--       , cuckName = "Tro Kalayjian"
--       , cuckSocial = "https://twitter.com/DoctorTro"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1261351818430255104?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "Dr. Tho engages in shitty behaviour that causes people to dislike him."
--               , dodgeNicksPosition = doxasticType.trueState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/tuckergoodrich.png"
--       , cuckName = "Tucker Goodrich"
--       , cuckSocial = "https://twitter.com/TuckerGoodrich"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1276694117494358017?s=19"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = "nutritional epidemiology is almost always wrong."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             , { dodgeLink = "https://twitter.com/TuckerGoodrich/status/1428062578668830720?s=20"
--               , dodgeDescription = dodgeType.ranAway
--               , dodgeProposition = propType.noClearProp
--               , dodgeNicksPosition = doxasticType.unevalState
--               }
--             , { dodgeLink = "https://twitter.com/TuckerGoodrich/status/1469366622196359170?s=20"
--               , dodgeDescription = dodgeType.outrightNo
--               , dodgeProposition = propType.noClearProp
--               , dodgeNicksPosition = doxasticType.unevalState
--               }
--             , { dodgeLink = "https://twitter.com/TuckerGoodrich/status/1470029816975872007?s=20"
--               , dodgeDescription = dodgeType.killScreen
--               , dodgeProposition = propType.noClearProp
--               , dodgeNicksPosition = doxasticType.unevalState
--               }
--             ]
--       }
--     , { cuckImage = "cucks/zoeharcombe.png"
--       , cuckName = "Zoe Harcombe"
--       , cuckSocial = "https://twitter.com/zoeharcombe"
--       , cuckDodges =
--             [ { dodgeLink = "https://twitter.com/The_Nutrivore/status/1418263706178310149"
--               , dodgeDescription = dodgeType.noReply
--               , dodgeProposition = "saturated fat doesn't increase the risk of coronary heart disease."
--               , dodgeNicksPosition = doxasticType.falseState
--               }
--             ]
--       }
--     ]
